Stoq - Open Source Business Management

#

## Open Source Business Management

Welcome to Stoq

## Contents

- About Stoq
- Business contact
- Technical contact
- License

### About Stoq

Stoq is configured in demonstration mode which you can use to test the software.

While using the Stoq in demonstration mode, the ECF plugin is enabled and uses an emulator to give a better idea how Stoq works with real hardware.

After installing and enabling production mode, the limitations and the emulator will be removed.

In case the username and password are asked::

- username: admin
- password: admin

### Business contact

For business related subjects, sending a proposal or scheduling a visit, contact our comercial department at <comercial@stoq.com.br>.

Or call us at +55 16 3376-0125

### Technical contact

To contact the Stoq team, ask a question or send a suggestion, check out the mailing list.

For questions about the development, architecture or usability, it's recommended to talk with Christian Reis at <comercial@stoq.com.br>.

To enter in contact with the team, go to the online chat.

### License

Stoq is licensed under GPL 2.0, for more information, see General Public License.